@@ -8,6 +8,7 @@
 #include "texteditor_plugin.h"
 #include "documenthandler.h"
 #include "colorschemesmodel.h"
+#include "linenumbermodel.h"
 
 void TextEditorPlugin::registerTypes(const char *uri)
 {
@@ -17,7 +18,9 @@ void TextEditorPlugin::registerTypes(const char *uri)
 
     qmlRegisterType<DocumentHandler>(uri, 1, 0, "DocumentHandler");
     qmlRegisterType<ColorSchemesModel>(uri, 1, 0, "ColorSchemesModel");
+    qmlRegisterType<LineNumberModel>(uri, 1, 0, "LineNumberModel");
     qmlRegisterType(componentUrl(QStringLiteral("TextEditor.qml")), uri, 1, 0, "TextEditor");
+    qmlRegisterType(componentUrl(QStringLiteral("ColorSchemesPage.qml")), uri, 1, 0, "ColorSchemesPage");
 }
 
 QUrl TextEditorPlugin::componentUrl(const QString &fileName) const
